@@ -4,16 +4,31 @@ from typing import List, Optional
 from pydantic import BaseModel
 
 
+class Kind(Enum):
+    dog = 'dog'
+    cat = 'cat'
+
+
 class Pet(BaseModel):
     id: int
     name: str
     tag: Optional[str] = None
+    kind: Optional['Kind'] = None
 
 
 class Pets(BaseModel):
     __root__: List['Pet']
 
 
+class Kind1(Enum):
+    snake = 'snake'
+    rabbit = 'rabbit'
+
+
+class Animal(BaseModel):
+    kind: Optional['Kind1'] = None
+
+
 class Error(BaseModel):
     code: int
     message: str
@@ -42,3 +57,11 @@ class AliasEnum(Enum):
     a = 1
     b = 2
     c = 3
+
+
+class MultipleTypeEnum(Enum):
+    red = 'red'
+    amber = 'amber'
+    green = 'green'
+    NoneType_None = None
+    int_42 = 42
