@@ -1,3 +1,4 @@
+from datamodel_code_generator import DataTypeManager
 from datamodel_code_generator.model import DataModelFieldBase
 from datamodel_code_generator.model.pydantic.custom_root_type import CustomRootType
 from datamodel_code_generator.types import DataType, Types
@@ -8,10 +9,7 @@ def test_custom_root_type():
         name='test_model',
         fields=[
             DataModelFieldBase(
-                name='a',
-                data_types=[DataType(type='str')],
-                default="'abc'",
-                required=False,
+                name='a', data_type=DataType(type='str'), default='abc', required=False,
             )
         ],
     )
@@ -19,7 +17,7 @@ def test_custom_root_type():
     assert custom_root_type.name == 'test_model'
     assert custom_root_type.fields == [
         DataModelFieldBase(
-            name='a', data_types=[DataType(type='str')], default="'abc'", required=False
+            name='a', data_type=DataType(type='str'), default='abc', required=False
         )
     ]
 
@@ -31,12 +29,12 @@ def test_custom_root_type():
 def test_custom_root_type_required():
     custom_root_type = CustomRootType(
         name='test_model',
-        fields=[DataModelFieldBase(data_types=[DataType(type='str')], required=True)],
+        fields=[DataModelFieldBase(data_type=DataType(type='str'), required=True)],
     )
 
     assert custom_root_type.name == 'test_model'
     assert custom_root_type.fields == [
-        DataModelFieldBase(data_types=[DataType(type='str')], required=True)
+        DataModelFieldBase(data_type=DataType(type='str'), required=True)
     ]
 
     assert custom_root_type.render() == (
@@ -47,14 +45,14 @@ def test_custom_root_type_required():
 def test_custom_root_type_decorator():
     custom_root_type = CustomRootType(
         name='test_model',
-        fields=[DataModelFieldBase(data_types=[DataType(type='str')], required=True)],
+        fields=[DataModelFieldBase(data_type=DataType(type='str'), required=True)],
         decorators=['@validate'],
         base_classes=['Base'],
     )
 
     assert custom_root_type.name == 'test_model'
     assert custom_root_type.fields == [
-        DataModelFieldBase(data_types=[DataType(type='str')], required=True)
+        DataModelFieldBase(data_type=DataType(type='str'), required=True)
     ]
     assert custom_root_type.base_class == 'Base'
     assert (
@@ -65,4 +63,4 @@ def test_custom_root_type_decorator():
 
 
 def test_custom_root_type_get_data_type():
-    assert CustomRootType.get_data_type(Types.integer) == DataType(type='int')
+    assert DataTypeManager().get_data_type(Types.integer) == DataType(type='int')
